@@ -213,7 +213,7 @@ private:
 	gr_cocoa_graphics_update	m_updateCallback;
 	void 						*m_updateCBparam;
 	XAP_CocoaNSView *  			m_pWin;
-	NSMutableDictionary*		m_fontProps;
+	ATSUStyle					m_atsuStyle;
 	CGContextRef				m_CGContext;
 	UT_GenericVector<id>		m_cacheArray;
 	UT_GenericVector<NSRect*>	m_cacheRectArray;
@@ -286,9 +286,7 @@ private:
 	/*!
 	  Wrapper to draw the char.
 
-	  \param cBuf the unichar buffer for the string
-	  \param len the length of the buffer
-	  \param fontProps the properties for the NSAttributedString
+	  \param atsuLayout the ATSU layout
 	  \param x X position
 	  \param y Y position
 	  \param begin the start of the range to draw
@@ -296,8 +294,9 @@ private:
 
 	  \note the NSView must be focused prior this call
 	 */
-	void _realDrawChars(const unichar* cBuf, int len, NSDictionary *fontProps, 
-						float x, float y, int begin, int rangelen);
+	void _realDrawChars(ATSUTextLayout atsuLayout,
+						float x, float y, int begin, int rangelen,
+						float xOffset);
 	//
 	StNSViewLocker* m_viewLocker;
 	//private font metrics objects
