@@ -385,6 +385,13 @@ void XAP_Win32Dialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		bDialogResult = GetOpenFileName((OPENFILENAME *)&ofn);
 		break;
 
+	case XAP_DIALOG_ID_INSERTMATHML:
+		ofn.lpstrTitle	 = pSS->getValue(XAP_STRING_ID_DLG_FOSA_InsertMath);
+		ofn.nFilterIndex = UT_pointerArrayLength((void **) m_szDescriptions) + 1;
+		ofn.Flags |= OFN_FILEMUSTEXIST;
+		bDialogResult = GetOpenFileName((OPENFILENAME *)&ofn);
+		break;
+
 	case XAP_DIALOG_ID_FILE_EXPORT:
 		ofn.lpstrTitle = pSS->getValue(XAP_STRING_ID_DLG_FOSA_ExportTitle);
 		ofn.lpfnHook	   = (LPOFNHOOKPROC) s_hookSaveAsProc;
@@ -733,7 +740,11 @@ UINT XAP_Win32Dialog_FileOpenSaveAs::_previewPicture(HWND hDlg)
 	PAINTSTRUCT ps;
 	HDC hdc = BeginPaint(hThumbnail, &ps);
 	FillRect(hdc, &r, GetSysColorBrush(COLOR_BTNFACE));
-	GR_Win32Graphics* pGr = new GR_Win32Graphics(hdc,hThumbnail,XAP_App::getApp());
+
+	GR_Win32AllocInfo ai(hdc,hThumbnail,XAP_App::getApp());
+	GR_Win32Graphics *pGr = (GR_Win32Graphics *)XAP_App::getApp()->newGraphics(ai);
+	UT_return_val_if_fail(pGr, false);
+	
 	pGr->drawImage(pImage,
 				   pGr->tlu((r.right	- scaled_width ) / 2),
 				   pGr->tlu((r.bottom - scaled_height) / 2));
