@@ -189,6 +189,7 @@ bool fp_Line::assertLineListIntegrity(void)
 			}
 			UT_ASSERT(pRunLine == pRunBlock);
 		}
+		UT_return_val_if_fail(pRunBlock,false);
 		pRunBlock = pRunBlock->getNextRun();
 	}
 	xxx_UT_DEBUGMSG(("Line %x Width of line is %d num runs is %d \n",this,width,k)); //   UT_ASSERT(width < getMaxWidth());
@@ -462,6 +463,10 @@ bool fp_Line::removeRun(fp_Run* pRun, bool bTellTheRunAboutIt)
 //	if(pPrevRun)
 //		pPrevRun->clearScreen();
 
+        if(pRun->getType() == FPRUN_FORCEDPAGEBREAK)
+	{
+	    getBlock()->forceSectionBreak();
+	}
 	if (bTellTheRunAboutIt)
 	{
 		pRun->setLine(NULL);
@@ -2607,6 +2612,11 @@ UT_sint32 fp_Line::getMarginBefore(void) const
 				{
 					pPrevC = pPrevC->getPrev();
 				}
+				else
+				{
+				    bLoop = false;
+				    return 0;
+				}
 			}
 		}
 		UT_sint32 iNextTopMargin = getBlock()->getTopMargin();
