@@ -101,8 +101,6 @@ fp_TextRun::~fp_TextRun()
         xxx_UT_DEBUGMSG(("!!!!!!!! Text run %x deleted \n",this));
 	DELETEP(m_pRenderInfo);
 	DELETEP(m_pItem);
-	FREEP(m_pLanguage);
-	m_pLanguage = NULL;
 }
 
 bool fp_TextRun::hasLayoutProperties(void) const
@@ -157,7 +155,8 @@ void fp_TextRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	/*
 	  TODO map line width to a property, not a hard-coded value
 	*/
-	bChanged |= _setLineWidth(UT_convertToLogicalUnits("0.8pt"));
+	static const UT_sint32 iLineWidth = _setLineWidth(UT_convertToLogicalUnits("0.8pt"));
+	bChanged |= _setLineWidth(iLineWidth);
 
 	UT_uint32 oldDecors = _getDecorations();
 	_setDecorations(0);
@@ -250,11 +249,13 @@ void fp_TextRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	UT_Language lls;
 	const XML_Char * pszLanguage = PP_evalProperty("lang",pSpanAP,pBlockAP,pSectionAP, pDoc, true);
 
+	// NB: m_pLanguage is a pointer into static tables inside UT_Language class and as
+	// such has a guaranteed life-span same as the application; hence no strdup here and
+	// no strcmp later
 	const XML_Char * pszOldLanguage = m_pLanguage;
-	FREEP(m_pLanguage);
-	m_pLanguage = UT_strdup(lls.getCodeFromCode(pszLanguage));
+	m_pLanguage = lls.getCodeFromCode(pszLanguage);
 	xxx_UT_DEBUGMSG(("!!!!!!!! Language of run set to %s pointer %x run %x \n",getLanguage(),m_pLanguage,this));
-	if(pszOldLanguage && (UT_strcmp(m_pLanguage,pszOldLanguage) != 0))
+	if(pszOldLanguage && (m_pLanguage != pszOldLanguage))
 	{
 	        UT_uint32 reason =  0;
 		if( getBlock()->getDocLayout()->getAutoSpellCheck())
@@ -945,7 +946,8 @@ bool fp_TextRun::canMergeWithNext(void)
 		|| (pNext->_getFont() != _getFont())
 		|| (getHeight() != pNext->getHeight())
 		|| (pNext->getField() != getField())
-		|| (UT_strcmp(pNext->m_pLanguage,m_pLanguage) != 0)	//this is not a bug
+		|| (pNext->m_pLanguage != m_pLanguage)	//this is not a bug; see m_pLanguage in
+												//fp_TextRun.h before modifying this line
 		|| (pNext->_getColorFG() != _getColorFG())
 		|| (pNext->_getColorHL() != _getColorHL())
 		|| (pNext->_getColorHL().isTransparent() != _getColorHL().isTransparent())
@@ -1010,7 +1012,8 @@ void fp_TextRun::mergeWithNext(void)
 	UT_ASSERT(getDescent() == pNext->getDescent());
 	UT_ASSERT(getHeight() == pNext->getHeight());
 	UT_ASSERT(_getLineWidth() == pNext->_getLineWidth());
-	UT_ASSERT(UT_strcmp(m_pLanguage,pNext->m_pLanguage) == 0); //this is not a bug
+	UT_ASSERT(m_pLanguage == pNext->m_pLanguage); //this is not a bug; see m_pLanguage in
+	                                              //fp_TextRun.h before modifying this line
 	UT_ASSERT(m_fPosition == pNext->m_fPosition);
 	UT_ASSERT(m_iDirOverride == pNext->m_iDirOverride); //#TF
 	//UT_ASSERT(m_iSpaceWidthBeforeJustification == pNext->m_iSpaceWidthBeforeJustification);
@@ -1143,8 +1146,7 @@ bool fp_TextRun::split(UT_uint32 iSplitOffset)
 	pNew->_setHeight(this->getHeight());
 	pNew->_setLineWidth(this->_getLineWidth());
 	pNew->_setDirty(true);
-	FREEP(pNew->m_pLanguage);
-	pNew->m_pLanguage = UT_strdup(this->m_pLanguage);
+	pNew->m_pLanguage = this->m_pLanguage;
 	xxx_UT_DEBUGMSG(("!!!!--- Run %x gets Language pointer %x \n",pNew,pNew->m_pLanguage));
 	pNew->_setDirection(this->_getDirection()); //#TF
 	pNew->m_iDirOverride = this->m_iDirOverride;
