@@ -1,3 +1,5 @@
+/* -*- mode: C++; tab-width: 4; c-basic-offset: 4; -*- */
+
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * Copyright (C) 2001 Hubert Figuiere
@@ -32,7 +34,7 @@
 #include "ap_LeftRuler.h"
 #include "gr_CocoaGraphics.h"
 class XAP_Frame;
-
+@class AP_CocoaLeftRulerDelegate;
 
 /*****************************************************************/
 
@@ -51,27 +53,17 @@ public:
 	NSWindow * 	getRootWindow(void);
 
 //	void _ruler_style_changed (void);
-	
+protected:
+	virtual void		_drawMarginProperties(const UT_Rect * pClipRect,
+											  AP_LeftRulerInfo * pInfo, 
+											  GR_Graphics::GR_Color3D clr);
+	virtual void		_drawCellMark(UT_Rect *prDrag, bool bUp);
 private:
 	static bool _graphicsUpdateCB(NSRect * aRect, GR_CocoaGraphics *pG, void* param);
 	
 	XAP_CocoaNSView *		m_wLeftRuler;
 	NSWindow *	m_rootWindow;
-
-#if 0
-	class _fe
-	{
-	public:
-		static gint button_press_event(GtkWidget * w, GdkEventButton * e);
-		static gint button_release_event(GtkWidget * w, GdkEventButton * e);
-		static gint configure_event(GtkWidget* w, GdkEventConfigure *e);
-		static gint motion_notify_event(GtkWidget* w, GdkEventMotion* e);
-		static gint key_press_event(GtkWidget* w, GdkEventKey* e);
-		static gint delete_event(GtkWidget * w, GdkEvent * /*event*/, gpointer /*data*/);
-		static gint abi_expose_repaint( gpointer /* AP_CocoaLeftRuler * */ p);
-		static void destroy (GtkWidget * /*widget*/, gpointer /*data*/);
-	};
-#endif
+	AP_CocoaLeftRulerDelegate* m_delegate;
 };
 
 #endif /* AP_COCOALEFTRULER_H */
