@@ -25,6 +25,7 @@
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 #include "ut_locale.h"
+
 #include "xap_App.h"
 #include "xap_Win32App.h"
 #include "xap_Win32FrameImpl.h"
@@ -62,14 +63,14 @@ void AP_Win32Dialog_Insert_DateTime::runModal(XAP_Frame * pFrame)
 
     LPCTSTR lpTemplate = NULL;
 
-    UT_ASSERT(m_id == AP_DIALOG_ID_INSERT_DATETIME);
+    UT_return_if_fail (m_id == AP_DIALOG_ID_INSERT_DATETIME);
 
     lpTemplate = MAKEINTRESOURCE(AP_RID_DIALOG_DATETIME);
 
     int result = DialogBoxParam(pWin32App->getInstance(),lpTemplate,
                 static_cast<XAP_Win32FrameImpl*>(pFrame->getFrameImpl())->getTopLevelWindow(),
                 (DLGPROC)s_dlgProc,(LPARAM)this);
-    UT_ASSERT((result != -1));
+    UT_ASSERT_HARMLESS((result != -1));
 }
 
 BOOL CALLBACK AP_Win32Dialog_Insert_DateTime::s_dlgProc(HWND hWnd,UINT msg,WPARAM wParam,LPARAM lParam)
@@ -107,16 +108,13 @@ void AP_Win32Dialog_Insert_DateTime::SetFormatsList(void)
 	pTime = &wide;
 #endif
 
-	UT_LocaleInfo localeInfo;
-	char *oldLocale = setlocale(LC_ALL, localeInfo.getLanguage().c_str());
+	UT_LocaleInfo localeInfo;                                               
+	UT_LocaleTransactor t(LC_ALL, localeInfo.getLanguage().utf8_str());
 
     for (i = 0;InsertDateTimeFmts[i] != NULL;i++) {
-    	
         strftime(szCurrentDateTime, CURRENT_DATE_TIME_SIZE, InsertDateTimeFmts[i], pTime);
         SendMessage(m_hwndFormats, LB_ADDSTRING, 0, (LPARAM)szCurrentDateTime);
     }
-    
-    setlocale(LC_ALL, oldLocale);
 }
 
 
