@@ -22,6 +22,7 @@
 
 #include "ap_Win32Frame.h"
 #include "ut_Win32Timer.h"
+#include "ut_Win32OS.h"
 #include "gr_Win32Graphics.h"
 #include "ap_Win32TopRuler.h"
 #include "ap_Win32LeftRuler.h"
@@ -39,6 +40,16 @@
 #define SPI_GETWHEELSCROLLLINES   104
 #endif
 
+// I really hate doing this, but this constant is only defined with _WIN32_WINNT >=
+// 0x0501, i.e., winXP, and I do not want to enable the lot
+#ifndef WM_UNICHAR
+#define WM_UNICHAR 0x109
+#endif
+
+#ifndef UNICODE_NOCHAR
+#define UNICODE_NOCHAR 0xFFFF
+#endif
+
 #define GWL(hwnd)		reinterpret_cast<AP_Win32Frame *>(GetWindowLong((hwnd), GWL_USERDATA))
 #define SWL(hwnd, f)	reinterpret_cast<AP_Win32Frame *>(SetWindowLong((hwnd), GWL_USERDATA,(LONG)(f)))
 
@@ -60,8 +71,7 @@ AP_Win32FrameImpl::AP_Win32FrameImpl(AP_Frame *pFrame) :
 	m_bMouseWheelTrack(false),
 	m_startMouseWheelY(0),
 	m_startScrollPosition(0),
-	m_bMouseActivateReceived(false),
-	m_bFirstAfterFocus(false)
+	m_bMouseActivateReceived(false)
 {
 }
 
@@ -74,7 +84,7 @@ XAP_FrameImpl * AP_Win32FrameImpl::createInstance(XAP_Frame *pFrame, XAP_App *pA
 {
 	XAP_FrameImpl *pFrameImpl = new AP_Win32FrameImpl(static_cast<AP_Frame *>(pFrame));
 
-	UT_ASSERT(pFrameImpl);
+	UT_ASSERT_HARMLESS(pFrameImpl);
 
 	return pFrameImpl;
 }
@@ -102,11 +112,11 @@ HWND AP_Win32FrameImpl::_createDocumentWindow(XAP_Frame *pFrame, HWND hwndParent
 	// the 'container' will in turn contain the document window, the
 	// rulers, and the variousscroll bars and other dead space.
 
-	m_hwndContainer = CreateWindowEx(WS_EX_CLIENTEDGE, s_ContainerWndClassName, NULL,
+	m_hwndContainer = UT_CreateWindowEx(WS_EX_CLIENTEDGE, s_ContainerWndClassName, NULL,
 									 WS_CHILD | WS_VISIBLE,
 									 iLeft, iTop, iWidth, iHeight,
 									 hwndParent, NULL, static_cast<XAP_Win32App *>(XAP_App::getApp())->getInstance(), NULL);
-	UT_ASSERT(m_hwndContainer);
+	UT_return_val_if_fail (m_hwndContainer, 0);
 	// WARNING!!! many places expect an XAP_Frame or descendant!!!
 	//SWL(m_hwndContainer, this);
 	SWL(m_hwndContainer, pFrame);
@@ -118,22 +128,22 @@ HWND AP_Win32FrameImpl::_createDocumentWindow(XAP_Frame *pFrame, HWND hwndParent
 	const int cyHScroll = GetSystemMetrics(SM_CYHSCROLL);
 	const int cxVScroll = GetSystemMetrics(SM_CXVSCROLL);
 
-	m_hWndHScroll = CreateWindowEx(0, "ScrollBar", 0, WS_CHILD | WS_VISIBLE | SBS_HORZ,
+	m_hWndHScroll = UT_CreateWindowEx(0, "ScrollBar", 0, WS_CHILD | WS_VISIBLE | SBS_HORZ,
 									0, r.bottom - cyHScroll,
 									r.right - cxVScroll, cyHScroll,
 									m_hwndContainer,
 									0, static_cast<XAP_Win32App *>(XAP_App::getApp())->getInstance(), 0);
-	UT_ASSERT(m_hWndHScroll);
+	UT_return_val_if_fail (m_hWndHScroll, 0);
 	// WARNING!!! many places expact an XAP_Frame or descendant!!!
 	//SWL(m_hWndHScroll, this);
 	SWL(m_hWndHScroll, pFrame);
 
-	m_hWndVScroll = CreateWindowEx(0, "ScrollBar", 0, WS_CHILD | WS_VISIBLE | SBS_VERT,
+	m_hWndVScroll = UT_CreateWindowEx(0, "ScrollBar", 0, WS_CHILD | WS_VISIBLE | SBS_VERT,
 									r.right - cxVScroll, 0,
 									cxVScroll, r.bottom - cyHScroll,
 									m_hwndContainer,
 									0, static_cast<XAP_Win32App *>(XAP_App::getApp())->getInstance(), 0);
-	UT_ASSERT(m_hWndVScroll);
+	UT_return_val_if_fail (m_hWndVScroll, 0);
 	// WARNING!!! many places expact an XAP_Frame or descendant!!!
 	//SWL(m_hWndVScroll, this);
 	SWL(m_hWndVScroll, pFrame);
@@ -144,12 +154,12 @@ HWND AP_Win32FrameImpl::_createDocumentWindow(XAP_Frame *pFrame, HWND hwndParent
 #  define XX_StyleBits          (SBS_SIZEGRIP)
 #endif
 
-	m_hWndGripperHack = CreateWindowEx(0,"ScrollBar", 0,
+	m_hWndGripperHack = UT_CreateWindowEx(0,"ScrollBar", 0,
 										WS_CHILD | WS_VISIBLE | XX_StyleBits,
 										r.right-cxVScroll, r.bottom-cyHScroll, cxVScroll, cyHScroll,
 										m_hwndContainer, NULL, static_cast<XAP_Win32App *>(XAP_App::getApp())->getInstance(), NULL);
 
-	UT_ASSERT(m_hWndGripperHack);
+	UT_return_val_if_fail (m_hWndGripperHack,0);
 	// WARNING!!! many places expact an XAP_Frame or descendant!!!
 	//SWL(m_hWndGripperHack, this);
 	SWL(m_hWndGripperHack, pFrame);
@@ -160,10 +170,10 @@ HWND AP_Win32FrameImpl::_createDocumentWindow(XAP_Frame *pFrame, HWND hwndParent
 	int xLeftRulerWidth = 0;
 
 	/* Create Graphics */
-	GR_Win32Graphics * pG = new GR_Win32Graphics(GetDC(m_hwndContainer), m_hwndContainer, 
-		XAP_App::getApp());
+	GR_Win32AllocInfo ai(GetDC(m_hwndContainer), m_hwndContainer, XAP_App::getApp());
+	GR_Win32Graphics * pG = (GR_Win32Graphics *)XAP_App::getApp()->newGraphics(ai);
 
-	UT_ASSERT(pG);	   
+	UT_return_val_if_fail (pG, 0);	   
 	
 	static_cast<AP_FrameData *>(pFrame->getFrameData())->m_pG = pG;
 
@@ -177,13 +187,15 @@ HWND AP_Win32FrameImpl::_createDocumentWindow(XAP_Frame *pFrame, HWND hwndParent
 	}
 
 	// create a child window for us.
-	m_hwndDocument = CreateWindowEx(0, s_DocumentWndClassName, NULL,
-									WS_CHILD | WS_VISIBLE,
-									xLeftRulerWidth, yTopRulerHeight,
-									r.right - xLeftRulerWidth - cxVScroll,
-									r.bottom - yTopRulerHeight - cyHScroll,
-									m_hwndContainer, NULL, static_cast<XAP_Win32App *>(XAP_App::getApp())->getInstance(), NULL);
-	UT_ASSERT(m_hwndDocument);
+	m_hwndDocument = UT_CreateWindowEx(0, s_DocumentWndClassName, NULL,
+									   WS_CHILD | WS_VISIBLE,
+									   xLeftRulerWidth, yTopRulerHeight,
+									   r.right - xLeftRulerWidth - cxVScroll,
+									   r.bottom - yTopRulerHeight - cyHScroll,
+									   m_hwndContainer, NULL,
+									   static_cast<XAP_Win32App *>(XAP_App::getApp())->getInstance(), NULL);
+	
+	UT_return_val_if_fail (m_hwndDocument, 0);
 	// WARNING!!! many places expact an XAP_Frame or descendant!!!
 	//SWL(m_hwndDocument, this);
 	SWL(m_hwndDocument, pFrame);
@@ -197,7 +209,7 @@ HWND AP_Win32FrameImpl::_createStatusBarWindow(XAP_Frame *pFrame, HWND hwndParen
 {
 	UT_return_val_if_fail(pFrame, NULL);
 	AP_Win32StatusBar * pStatusBar = new AP_Win32StatusBar(pFrame);
-	UT_ASSERT(pStatusBar);
+	UT_return_val_if_fail (pStatusBar, 0);
 	_setHwndStatusBar(pStatusBar->createWindow(hwndParent,iLeft,iTop,iWidth));
 	static_cast<AP_FrameData *>(pFrame->getFrameData())->m_pStatusBar = pStatusBar;
 
@@ -206,12 +218,12 @@ HWND AP_Win32FrameImpl::_createStatusBarWindow(XAP_Frame *pFrame, HWND hwndParen
 
 void AP_Win32FrameImpl::_refillToolbarsInFrameData() 
 {
-	UT_ASSERT(UT_NOT_IMPLEMENTED);
+	UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
 }
 
 void AP_Win32FrameImpl::_rebuildToolbar(UT_uint32 ibar)
 {
-	UT_ASSERT(UT_NOT_IMPLEMENTED);
+	UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
 }
 
 void AP_Win32FrameImpl::_toggleBar(UT_uint32 iBarNb, bool bBarOn)
@@ -237,7 +249,7 @@ void AP_Win32FrameImpl::_toggleBar(UT_uint32 iBarNb, bool bBarOn)
 	{
 		EV_Win32Toolbar *pThisToolbar = (EV_Win32Toolbar *)m_vecToolbars.getNthItem(i);
 
-		UT_ASSERT(pThisToolbar);
+		UT_ASSERT_HARMLESS(pThisToolbar);
 
 		if (pThisToolbar)	// release build paranoia
 			if ( pThisToolbar->bVisible() )
@@ -293,7 +305,7 @@ void AP_Win32FrameImpl::_bindToolbars(AV_View *pView)
 void AP_Win32FrameImpl::_showOrHideToolbars(void)
 {
 	XAP_Frame* pFrame = getFrame();
-	UT_ASSERT( pFrame );
+	UT_return_if_fail ( pFrame );
 	bool *bShowBar = static_cast<AP_FrameData *>(pFrame->getFrameData())->m_bShowBar;
 
 	for (UT_uint32 i = 0; i < m_vecToolbarLayoutNames.getItemCount(); i++)
@@ -306,7 +318,7 @@ void AP_Win32FrameImpl::_showOrHideToolbars(void)
 void AP_Win32FrameImpl::_showOrHideStatusbar(void)
 {
 	XAP_Frame* pFrame = getFrame();
-	UT_ASSERT( pFrame );
+	UT_return_if_fail ( pFrame );
 	bool bShowStatusBar = static_cast<AP_FrameData *>(pFrame->getFrameData())->m_bShowStatusBar;
 	pFrame->toggleStatusBar(bShowStatusBar);
 }
@@ -347,7 +359,7 @@ void AP_Win32FrameImpl::_createTopRuler(XAP_Frame *pFrame)
 
 	// create the top ruler
 	AP_Win32TopRuler * pWin32TopRuler = new AP_Win32TopRuler(pFrame);
-	UT_ASSERT(pWin32TopRuler);
+	UT_return_if_fail (pWin32TopRuler);
 	m_hwndTopRuler = pWin32TopRuler->createWindow(m_hwndContainer,
 												  0,0, (r.right - cxVScroll));
 	static_cast<AP_FrameData *>(pFrame->getFrameData())->m_pTopRuler = pWin32TopRuler;
@@ -387,7 +399,7 @@ void AP_Win32FrameImpl::_createLeftRuler(XAP_Frame *pFrame)
 
 	// create the left ruler
 	AP_Win32LeftRuler * pWin32LeftRuler = new AP_Win32LeftRuler(pFrame);
-	UT_ASSERT(pWin32LeftRuler);
+	UT_return_if_fail (pWin32LeftRuler);
 	m_hwndLeftRuler = pWin32LeftRuler->createWindow(m_hwndContainer,0,yTopRulerHeight,
 													r.bottom - yTopRulerHeight - cyHScroll);
 	static_cast<AP_FrameData *>(pFrame->getFrameData())->m_pLeftRuler = pWin32LeftRuler;
@@ -577,7 +589,6 @@ bool AP_Win32FrameImpl::_RegisterClass(XAP_Win32App * app)
 	if (!XAP_Win32FrameImpl::_RegisterClass(app))
 		return false;
 
-	WNDCLASSEX  wndclass;
 	ATOM a;
 
 	// register class for the container window (this will contain the document
@@ -585,41 +596,19 @@ bool AP_Win32FrameImpl::_RegisterClass(XAP_Win32App * app)
 
 	_snprintf(s_ContainerWndClassName, MAXCNTWNDCLSNMSIZE, "%sContainer", app->getApplicationName());
 
-	memset(&wndclass, 0, sizeof(wndclass));
-	wndclass.cbSize        = sizeof(wndclass);
-	wndclass.style         = CS_DBLCLKS | CS_OWNDC;
-	wndclass.lpfnWndProc   = AP_Win32FrameImpl::_ContainerWndProc;
-	wndclass.cbClsExtra    = 0;
-	wndclass.cbWndExtra    = 0;
-	wndclass.hInstance     = app->getInstance();
-	wndclass.hIcon         = NULL;
-	wndclass.hCursor       = LoadCursor(NULL, IDC_ARROW);
-	wndclass.hbrBackground = NULL;
-	wndclass.lpszMenuName  = NULL;
-	wndclass.lpszClassName = s_ContainerWndClassName;
-	wndclass.hIconSm       = NULL;
-
-	a = RegisterClassEx(&wndclass);
+	a = UT_RegisterClassEx(CS_DBLCLKS | CS_OWNDC, AP_Win32FrameImpl::_ContainerWndProc, app->getInstance(),
+						   NULL, LoadCursor(NULL, IDC_ARROW), NULL, NULL,
+						   NULL, s_ContainerWndClassName);
+	
 	UT_return_val_if_fail(a, false);
 
 	// register class for the actual document window
 	_snprintf(s_DocumentWndClassName, MAXDOCWNDCLSNMSIZE, "%sDocument", app->getApplicationName());
 
-	memset(&wndclass, 0, sizeof(wndclass));
-	wndclass.cbSize        = sizeof(wndclass);
-	wndclass.style         = CS_DBLCLKS | CS_OWNDC;
-	wndclass.lpfnWndProc   = AP_Win32FrameImpl::_DocumentWndProc;
-	wndclass.cbClsExtra    = 0;
-	wndclass.cbWndExtra    = 0;
-	wndclass.hInstance     = app->getInstance();
-	wndclass.hIcon         = NULL;
-	wndclass.hCursor       = NULL;
-	wndclass.hbrBackground = NULL;
-	wndclass.lpszMenuName  = NULL;
-	wndclass.lpszClassName = s_DocumentWndClassName;
-	wndclass.hIconSm       = NULL;
+	a = UT_RegisterClassEx(CS_DBLCLKS | CS_OWNDC, AP_Win32FrameImpl::_DocumentWndProc, app->getInstance(),
+						   NULL, NULL, NULL, NULL,
+						   NULL, s_DocumentWndClassName);
 
-	a = RegisterClassEx(&wndclass);
 	UT_return_val_if_fail(a, false);
 
 	if (!AP_Win32TopRuler::RegisterClass(app) ||
@@ -818,11 +807,11 @@ LRESULT CALLBACK AP_Win32FrameImpl::_ContainerWndProc(HWND hwnd, UINT iMsg, WPAR
 
 	if (!f)
 	{
-		return DefWindowProc(hwnd, iMsg, wParam, lParam);
+		return UT_DefWindowProc(hwnd, iMsg, wParam, lParam);
 	}
 
 	AP_Win32FrameImpl *fImpl = f->getAPWin32FrameImpl();
-	UT_return_val_if_fail(fImpl, DefWindowProc(hwnd, iMsg, wParam, lParam));
+	UT_return_val_if_fail(fImpl, UT_DefWindowProc(hwnd, iMsg, wParam, lParam));
 
 	AV_View* pView = f->getCurrentView();
 	//UT_ASSERT(pView);		/* only fatal for some messages */
@@ -951,7 +940,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_ContainerWndProc(HWND hwnd, UINT iMsg, WPAR
 			SendMessage(fImpl->m_hwndTopRuler,WM_SYSCOLORCHANGE,0,0);
 			SendMessage(fImpl->m_hwndLeftRuler,WM_SYSCOLORCHANGE,0,0);
 			SendMessage(fImpl->m_hwndDocument,WM_SYSCOLORCHANGE,0,0);
-			return DefWindowProc(hwnd, iMsg, wParam, lParam);
+			return UT_DefWindowProc(hwnd, iMsg, wParam, lParam);
 		}
 
 	 	case WM_MOUSEWHEEL:
@@ -966,6 +955,8 @@ LRESULT CALLBACK AP_Win32FrameImpl::_ContainerWndProc(HWND hwnd, UINT iMsg, WPAR
  					pMouse->onButtonWheel(pView,hwnd,EV_EMB_BUTTON4,wParam,LOWORD(lParam),HIWORD(lParam));
  				else
  					pMouse->onButtonWheel(pView,hwnd,EV_EMB_BUTTON5,wParam,LOWORD(lParam),HIWORD(lParam));
+
+				break;
 			} 			
  			
 			const int cWheelLines = _getMouseWheelLines();
@@ -1010,21 +1001,23 @@ LRESULT CALLBACK AP_Win32FrameImpl::_ContainerWndProc(HWND hwnd, UINT iMsg, WPAR
 		}
 
 		default:
-			return DefWindowProc(hwnd, iMsg, wParam, lParam);
+			return UT_DefWindowProc(hwnd, iMsg, wParam, lParam);
 	}
+
+	return 0; // to silence the compiler
 }
 
 LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARAM wParam, LPARAM lParam)
 {
 	AP_Win32Frame * f = reinterpret_cast<AP_Win32Frame *>(GetWindowLong(hwnd, GWL_USERDATA));
 
-	if (!f)
+	if (!f || !IsWindow(hwnd))
 	{
-		return DefWindowProc(hwnd, iMsg, wParam, lParam);
+		return UT_DefWindowProc(hwnd, iMsg, wParam, lParam);
 	}
 
 	AP_Win32FrameImpl *fImpl = static_cast<AP_Win32FrameImpl *>(f->getFrameImpl());
-	UT_return_val_if_fail(fImpl, DefWindowProc(hwnd, iMsg, wParam, lParam));
+	UT_return_val_if_fail(fImpl, UT_DefWindowProc(hwnd, iMsg, wParam, lParam));
 
 	AV_View* 		pView = f->getCurrentView();
 	EV_Win32Mouse*	pMouse = (EV_Win32Mouse *) fImpl->m_pMouse;
@@ -1039,9 +1032,6 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 			if (pView)
 			{					
 				pView->focusChange(AV_FOCUS_HERE);
-			
-				if (GetKeyState(VK_LBUTTON)>0)
-					fImpl->m_bFirstAfterFocus = true;
 
 				if(!fImpl->m_bMouseActivateReceived)
 				{
@@ -1076,21 +1066,14 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 		}
 
 		case WM_LBUTTONDOWN:
-		
-			/* When we get the focus back 					*/
-			if (fImpl->m_bFirstAfterFocus)
-				fImpl->m_bFirstAfterFocus = false;	
-			else
+			if(GetFocus() != hwnd)
 			{
-				if(GetFocus() != hwnd)
-				{
-					SetFocus(hwnd);
-					pView = f->getCurrentView();
-					pMouse = (EV_Win32Mouse *) fImpl->m_pMouse;
-				}
-				pMouse->onButtonDown(pView,hwnd,EV_EMB_BUTTON1,wParam,LOWORD(lParam),HIWORD(lParam));
-				fImpl->m_bMouseActivateReceived = false;
+				SetFocus(hwnd);
+				pView = f->getCurrentView();
+				pMouse = (EV_Win32Mouse *) fImpl->m_pMouse;
 			}
+			pMouse->onButtonDown(pView,hwnd,EV_EMB_BUTTON1,wParam,LOWORD(lParam),HIWORD(lParam));
+			fImpl->m_bMouseActivateReceived = false;
 			return 0;
 
 		case WM_MBUTTONDOWN:
@@ -1135,7 +1118,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 
 	    
 	     	if (pWin32Keyboard->onKeyDown(pView,hwnd,iMsg,wParam,lParam))
-    			return DefWindowProc(hwnd,iMsg,wParam,lParam);
+    			return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
 	 		else
  				return false;	    				 	     			
 		
@@ -1203,7 +1186,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 
 	    
 		     	if (pWin32Keyboard->onKeyDown(pView,hwnd,iMsg,wParam,lParam))
-     				return DefWindowProc(hwnd,iMsg,wParam,lParam);
+     				return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
 	 		else
  				return false;	    				 	     			
     		
@@ -1213,7 +1196,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 		{
 			UT_DEBUGMSG(("WM_SYSCHAR %d  - %d\n",wParam, lParam));
 			ev_Win32Keyboard *pWin32Keyboard = static_cast<ev_Win32Keyboard *>(fImpl->m_pKeyboard);	    
-			return DefWindowProc(hwnd,iMsg,wParam,lParam);
+			return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
 		}
 
 		case WM_CHAR:
@@ -1222,7 +1205,21 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 			ev_Win32Keyboard *pWin32Keyboard = static_cast<ev_Win32Keyboard *>(fImpl->m_pKeyboard);
 	    
 			pWin32Keyboard->onChar(pView,hwnd,iMsg,wParam,lParam);		
-			return DefWindowProc(hwnd,iMsg,wParam,lParam);
+			return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
+		}
+
+		case WM_UNICHAR:
+		{
+			UT_DEBUGMSG(("WM_CHAR %d  - %d\n",wParam, lParam));
+
+			// UNICODE_NOCHAR is sent to test if we can handle this message
+			if(wParam == UNICODE_NOCHAR)
+				return 1;
+			
+			ev_Win32Keyboard *pWin32Keyboard = static_cast<ev_Win32Keyboard *>(fImpl->m_pKeyboard);
+	    
+			pWin32Keyboard->onUniChar(pView,hwnd,iMsg,wParam,lParam);		
+			return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
 		}
 
 		case WM_IME_CHAR:
@@ -1230,7 +1227,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 			ev_Win32Keyboard *pWin32Keyboard = static_cast<ev_Win32Keyboard *>(fImpl->m_pKeyboard);
 			if (pWin32Keyboard->onIMEChar(pView,hwnd,iMsg,wParam,lParam))
 				return 0;
-			return DefWindowProc(hwnd,iMsg,wParam,lParam);
+			return UT_DefWindowProc(hwnd,iMsg,wParam,lParam);
 		}
 
 		case WM_MOUSEMOVE:
@@ -1327,7 +1324,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 		case WM_TIMER:
 		{
 			TIMERPROC * pfn = (TIMERPROC *)lParam;
-			UT_ASSERT( (void *)(pfn) == (void *)(Global_Win32TimerProc) );
+			UT_ASSERT_HARMLESS( (void *)(pfn) == (void *)(Global_Win32TimerProc) );
 			Global_Win32TimerProc(hwnd,WM_TIMER,(UINT)wParam,NULL);
 			return 0;
 		}
@@ -1352,7 +1349,7 @@ LRESULT CALLBACK AP_Win32FrameImpl::_DocumentWndProc(HWND hwnd, UINT iMsg, WPARA
 #endif
 	} /* switch (iMsg) */
 
-	return DefWindowProc(hwnd, iMsg, wParam, lParam);
+	return UT_DefWindowProc(hwnd, iMsg, wParam, lParam);
 }
 
 UT_RGBColor AP_Win32FrameImpl::getColorSelBackground () const
@@ -1370,3 +1367,9 @@ UT_RGBColor AP_Win32FrameImpl::getColorSelBackground () const
 
 	return UT_RGBColor( red, green, blue );
 }
+
+GR_Win32Graphics *AP_Win32FrameImpl::createDocWndGraphics(void)
+{
+	GR_Win32AllocInfo ai(GetDC(getHwndDocument()), getHwndDocument(), XAP_App::getApp());
+	return (GR_Win32Graphics *)XAP_App::getApp()->newGraphics(ai);
+}
