@@ -23,13 +23,15 @@ extern "C" {
 # include <fcntl.h>       /* for mode_t */
 #else
 # include <stdlib.h>
-#ifdef __MINGW32__
+#if defined(__MINGW32__) || defined(__WINE__)
 # include <sys/types.h>
 #else
 	typedef unsigned long mode_t;
 	typedef long off_t;
 #endif
+#ifndef _SSIZE_T_
 	typedef size_t ssize_t;
+#endif
 	typedef long caddr_t;
 #endif
 
